@@ -1608,7 +1608,7 @@ non-nil."
   ())
 
 (defun sc-no-blank-line-or-header()
-  "Similar to `sc-no-header' except it removes the preceeding blank line."
+  "Similar to `sc-no-header' except it removes the preceding blank line."
   (if (not (bobp))
       (if (and (eolp)
 	       (progn (forward-line -1)
